@@ -2,7 +2,7 @@ package Net::DNS::RR::GPOS;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: GPOS.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+our $VERSION = (qw$Id: GPOS.pm 2003 2025-01-21 12:06:06Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -20,13 +20,14 @@ use Net::DNS::Text;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	my $limit = $offset + $self->{rdlength};
-	( $self->{latitude},  $offset ) = Net::DNS::Text->decode( $data, $offset ) if $offset < $limit;
-	( $self->{longitude}, $offset ) = Net::DNS::Text->decode( $data, $offset ) if $offset < $limit;
-	( $self->{altitude},  $offset ) = Net::DNS::Text->decode( $data, $offset ) if $offset < $limit;
+	for (qw(latitude longitude altitude)) {
+		my $text;
+		( $text, $offset ) = Net::DNS::Text->decode( $data, $offset );
+		$self->$_( $text->value );
+	}
 	croak('corrupt GPOS data') unless $offset == $limit;	# more or less FUBAR
 	return;
 }
@@ -35,26 +36,23 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless defined $self->{altitude};
-	return join '', map { $self->{$_}->encode } qw(latitude longitude altitude);
+	return join '', map { Net::DNS::Text->new($_)->encode } @{$self}{qw(latitude longitude altitude)};
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless defined $self->{altitude};
-	return join ' ', map { $self->{$_}->string } qw(latitude longitude altitude);
+	return map { Net::DNS::Text->new($_)->string } @{$self}{qw(latitude longitude altitude)};
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->latitude(shift);
-	$self->longitude(shift);
-	$self->altitude(shift);
-	die 'too many arguments for GPOS' if scalar @_;
+	$self->latitude( shift @argument );
+	$self->longitude( shift @argument );
+	$self->altitude(@argument);
 	return;
 }
 
@@ -68,35 +66,31 @@ sub _defaults {				## specify RR attribute default values
 
 
 sub latitude {
-	my $self = shift;
-	$self->{latitude} = _fp2text(shift) if scalar @_;
-	return defined(wantarray) ? _text2fp( $self->{latitude} ) : undef;
+	my ( $self, @value ) = @_;
+	for (@value) { return $self->{latitude} = _fp($_) }
+	return $self->{latitude};
 }
 
 
 sub longitude {
-	my $self = shift;
-	$self->{longitude} = _fp2text(shift) if scalar @_;
-	return defined(wantarray) ? _text2fp( $self->{longitude} ) : undef;
+	my ( $self, @value ) = @_;
+	for (@value) { return $self->{longitude} = _fp($_) }
+	return $self->{longitude};
 }
 
 
 sub altitude {
-	my $self = shift;
-	$self->{altitude} = _fp2text(shift) if scalar @_;
-	return defined(wantarray) ? _text2fp( $self->{altitude} ) : undef;
+	my ( $self, @value ) = @_;
+	for (@value) { return $self->{altitude} = _fp($_) }
+	return $self->{altitude};
 }
 
 
 ########################################
 
-sub _fp2text {
-	return Net::DNS::Text->new( sprintf( '%1.10g', shift ) );
-}
-
-sub _text2fp {
+sub _fp {
 	no integer;
-	return ( 0.0 + shift->value );
+	return sprintf( '%1.10g', 0.0 + shift );
 }
 
 ########################################
@@ -108,8 +102,8 @@ __END__
 
 =head1 SYNOPSIS
 
-    use Net::DNS;
-    $rr = Net::DNS::RR->new('name GPOS latitude longitude altitude');
+	use Net::DNS;
+	$rr = Net::DNS::RR->new('name GPOS latitude longitude altitude');
 
 =head1 DESCRIPTION
 
@@ -127,22 +121,22 @@ other unpredictable behaviour.
 
 =head2 latitude
 
-    $latitude = $rr->latitude;
-    $rr->latitude( $latitude );
+	$latitude = $rr->latitude;
+	$rr->latitude( $latitude );
 
 Floating-point representation of latitude, in degrees.
 
 =head2 longitude
 
-    $longitude = $rr->longitude;
-    $rr->longitude( $longitude );
+	$longitude = $rr->longitude;
+	$rr->longitude( $longitude );
 
 Floating-point representation of longitude, in degrees.
 
 =head2 altitude
 
-    $altitude = $rr->altitude;
-    $rr->altitude( $altitude );
+	$altitude = $rr->altitude;
+	$rr->altitude( $altitude );
 
 Floating-point representation of altitude, in metres.
 
@@ -177,6 +171,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1712
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1712|https://iana.org/go/rfc1712>
 
 =cut
