@@ -1,9 +1,8 @@
 package Net::DNS::Resolver::UNIX;
 
-#
-# $Id: UNIX.pm 1527 2017-01-18 21:42:48Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1527 $)[1];
+use strict;
+use warnings;
+our $VERSION = (qw$Id: UNIX.pm 2007 2025-02-08 16:45:23Z willem $)[2];
 
 
 =head1 NAME
@@ -13,40 +12,32 @@ Net::DNS::Resolver::UNIX - Unix resolver class
 =cut
 
 
-use strict;
-use warnings;
-use base qw(Net::DNS::Resolver::Base);
+my @config_file = grep { -f $_ && -r $_ } '/etc/resolv.conf';
+
+my $homedir = $ENV{HOME};
+my $dotfile = '.resolv.conf';
+my @dotfile = grep { -f $_ && -o $_ } map {"$_/$dotfile"} grep {$_} $homedir, '.';
 
 
-my $resolv_conf = "/etc/resolv.conf";
-my $dotfile	= '.resolv.conf';
-
-my @resolv_conf = grep -f $_ && -r _, $resolv_conf;
-
-my @config_path;
-push( @config_path, $ENV{HOME} ) if exists $ENV{HOME};
-push( @config_path, '.' );
-
-my @config_file = grep -f $_ && -o _, map "$_/$dotfile", @config_path;
-
-
-sub _untaint {
-	map { m/^(.*)$/; $1 } grep defined, @_;
-}
+my $path = $ENV{PATH};
+local $ENV{PATH} = join ':', grep {$_} qw(/bin /usr/bin), $path;
+my $uname = eval {`uname -n 2>/dev/null`} || '';
+chomp $uname;
+my ( $host, @domain ) = split /\./, $uname, 2;
 
 
 sub _init {
 	my $defaults = shift->_defaults;
 
-	map $defaults->_read_config_file($_), @resolv_conf;
+	$defaults->domain(@domain);
+	$defaults->_read_config_file($_) foreach @config_file;
 
-	foreach my $attr (qw(nameservers searchlist)) {
-		$defaults->$attr( _untaint $defaults->$attr() );
-	}
+	%$defaults = Net::DNS::Resolver::Base::_untaint(%$defaults);
 
-	map $defaults->_read_config_file($_), @config_file;
+	$defaults->_read_config_file($_) foreach @dotfile;
 
 	$defaults->_read_env;
+	return;
 }
 
 
@@ -56,7 +47,7 @@ __END__
 
 =head1 SYNOPSIS
 
-    use Net::DNS::Resolver;
+	use Net::DNS::Resolver;
 
 =head1 DESCRIPTION
 
@@ -75,7 +66,7 @@ All rights reserved.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
